"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var base_1 = require("../base");
var util_1 = require("../../util");
var definition_1 = require("../../definition");
var link_1 = require("../link");
var Button = /** @class */ (function (_super) {
    __extends(Button, _super);
    function Button() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [02.02.2020]
     * @returns {JSX.Element}
     */
    Button.prototype.render = function () {
        var _this = this;
        var props = this.props;
        var $text = this.text;
        var $hasContent = this.hasContent($text);
        var $hasIcon = util_1.hasIcon(props);
        var $isIconLeftAligned = util_1.isIconLeftAligned(props);
        var className = util_1.joinClassName(definition_1.ButtonClassesEnum.BUTTON, util_1.calc(props.className), $hasContent ? 'rac-button-filled' : 'rac-button-not-filled', this.isFull && definition_1.ButtonClassesEnum.FULL_BUTTON, this.isDecorated && $hasIcon && 'rac-button-decorated', props.mini && 'rac-button-mini', props.outlined && 'rac-button-outlined', props.raised && definition_1.ButtonClassesEnum.BUTTON_RAISED);
        if (props.to) {
            return (React.createElement(link_1.Link, { to: props.to, style: props.style, className: className }, $text));
        }
        var disabled = this.isDisabled;
        var iconElement = $hasIcon && this.iconElement;
        return (React.createElement(definition_1.UniversalIdProviderContext.Consumer, null, function (identificator) { return (React.createElement("button", __assign({ id: _this.getId(identificator), ref: _this.selfRef, type: props.type, title: props.title, style: props.style, className: className, disabled: disabled }, util_1.handlerPropsFactory(props.onClick, !disabled, props.touched), { onMouseEnter: props.onMouseEnter, onMouseLeave: props.onMouseLeave }),
            $isIconLeftAligned && iconElement,
            $hasContent && (React.createElement("div", { className: 'rac-button__content' },
                $text && _this.t($text),
                props.children)),
            !$isIconLeftAligned && iconElement)); }));
    };
    /**
     * @stable [23.02.2019]
     */
    Button.prototype.blur = function () {
        this.getSelf().blur(); // document.activeElement === body
    };
    // TODO
    Button.prototype.getId = function (identificator) {
        if (R.isNil(identificator)) {
            return identificator;
        }
        var names = [this.props.text];
        return names.map(function (name) { return (name || '').split(' ').map(function (part) { return (part[0] || '').toLowerCase(); }).join('-'); }).join('-');
    };
    Object.defineProperty(Button.prototype, "isDecorated", {
        /**
         * @stable [02.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isDecorated(this.props);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [02.02.2020]
     * @param text
     * @returns {boolean}
     */
    Button.prototype.hasContent = function (text) {
        return util_1.isObjectNotEmpty(this.props.children) || util_1.isObjectNotEmpty(text);
    };
    Object.defineProperty(Button.prototype, "isDisabled", {
        /**
         * @stable [02.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isDisabled(this.props) || util_1.inProgress(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Button.prototype, "isFull", {
        /**
         * @stable [02.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isFull(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Button.prototype, "iconElement", {
        /**
         * @stable [02.02.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _a = this.props, error = _a.error, icon = _a.icon, progress = _a.progress;
            return this.uiFactory.makeIcon({
                type: progress
                    ? 'spinner'
                    : (error ? 'error' : icon),
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Button.prototype, "text", {
        /**
         * @stable [02.02.2020]
         * @returns {string}
         */
        get: function () {
            var _a = this.props, error = _a.error, errorMessage = _a.errorMessage, progress = _a.progress, progressMessage = _a.progressMessage, text = _a.text;
            return (progress
                ? util_1.nvl(progressMessage, this.settings.messages.WAITING)
                : (error
                    ? util_1.nvl(errorMessage, this.settings.messages.ERROR)
                    : text));
        },
        enumerable: true,
        configurable: true
    });
    Button.defaultProps = {
        full: false,
        touched: false,
        type: 'button',
    };
    return Button;
}(base_1.BaseComponent));
exports.Button = Button;
//# sourceMappingURL=button.component.js.map