/// <reference types="react" />
import { ILogger } from 'ts-smart-logger';
import { BaseTextField } from '../text-field';
import { AnyT, EntityIdT } from '../../../definitions.interface';
import { IBaseSelect, IBaseSelectProps, IBaseSelectState } from './base-select.interface';
import { IBaseEvent, IMenuProps, ISelectOptionEntity } from '../../../definition';
export declare class BaseSelect<TProps extends IBaseSelectProps, TState extends IBaseSelectState> extends BaseTextField<TProps, TState> implements IBaseSelect {
    protected static readonly logger: ILogger;
    private readonly menuRef;
    private readonly quickFilterQueryTask;
    /**
     * @stable [30.11.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    onChange(event: IBaseEvent): void;
    /**
     * @stable [29.01.2020]
     * @param {Readonly<TProps extends IBaseSelectProps>} prevProps
     * @param {Readonly<TState extends IBaseSelectState>} prevState
     */
    componentDidUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>): void;
    /**
     * @stable [31.01.2020]
     */
    componentWillUnmount(): void;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    onKeyEscape(event: IBaseEvent): void;
    /**
     * @stable [30.01.2020]
     */
    clearValue(): void;
    /**
     * @stable [11.01.2020]
     */
    openMenu(): void;
    /**
     * @stable [16.01.2020]
     * @param {IBaseEvent} event
     */
    onKeyEnter(event: IBaseEvent): void;
    /**
     * @stable [28.01.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    protected readonly inputAttachmentElement: JSX.Element;
    /**
     * @stable [09.01.2020]
     * @returns {IMenuProps}
     */
    protected getMenuProps(): IMenuProps;
    /**
     * @stable [31.01.2020]
     * @param {(option: ISelectOptionEntity) => boolean} filter
     * @returns {ISelectOptionEntity[]}
     */
    protected getFilteredOptions(filter?: (option: ISelectOptionEntity) => boolean): ISelectOptionEntity[];
    /**
     * @stable [28.01.2020]
     * @returns {boolean}
     */
    protected isFieldBusy(): boolean;
    /**
     * @stable [11.01.2020]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [21.12.2019]
     * @returns {AnyT}
     */
    protected readonly originalEmptyValue: AnyT;
    /**
     * @stable [28.01.2020]
     * @param {ISelectOptionEntity} option
     */
    protected onSelect(option: ISelectOptionEntity): void;
    /**
     * @stable [11.01.2020]
     * @param {ISelectOptionEntity} option
     */
    protected notifySelectOption(option: ISelectOptionEntity): void;
    /**
     * @stable [10.09.2019]
     */
    protected onClose(): void;
    /**
     * @stable [28.01.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected getDecoratedDisplayValue(value: AnyT): AnyT;
    /**
     * @stable [28.01.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected decorateDisplayValue(value: AnyT): AnyT;
    /**
     * @stable [11.01.2020]
     * @returns {ISelectOptionEntity[]}
     */
    protected readonly options: ISelectOptionEntity[];
    /**
     * @stable [11.01.2020]
     * @returns {boolean}
     */
    protected readonly isExpandActionRendered: boolean;
    /**
     * @stable [28.01.2020]
     * @returns {boolean}
     */
    protected readonly isAllowEmptyFilterValue: boolean;
    /**
     * @stable [28.01.2020]
     * @returns {EntityIdT}
     */
    protected selectOptionEntityAsId(value: AnyT): EntityIdT;
    /**
     * @stable [28.01.2020]
     */
    private notifyQuickSearchFilterChange;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    private onDropDownClick;
    /**
     * @stable [28.01.2020]
     * @param {ISelectOptionEntity} option
     */
    private doSelectOption;
    /**
     * @stable [01.02.2020]
     * @param {string} query
     */
    private onFilterChange;
    /**
     * @stable [11.01.2020]
     */
    private hideMenu;
    /**
     * @stable [12.01.2020]
     * @param {boolean} force
     */
    private renderAndShowMenu;
    /**
     * @stable [16.01.2020]
     */
    private startQuickSearchIfApplicable;
    /**
     * @stable [28.01.2020]
     */
    private onOptionsLoadDone;
    /**
     * @stable [30.01.2020]
     * @param {boolean} noDelay
     */
    private hideMenuAndStartQuickSearch;
    /**
     * @stable [29.01.2020]
     * @param {TProps} props
     * @param {TProps} previousProps
     */
    private tryResetCachedValue;
    /**
     * @stable [31.01.2020]
     */
    private cancelQueryFilterTask;
    /**
     * @stable [30.01.2020]
     * @param {() => void} callback
     */
    private clearCachedValue;
    /**
     * @stable [30.01.2020]
     * @param {ISelectOptionEntity} value
     * @param {() => void} callback
     */
    private saveCachedValue;
    /**
     * @stable [31.01.2020]
     * @param {ISelectOptionEntity | StringNumberT} value
     * @returns {StringNumberT}
     */
    private selectOptionEntityAsDisplayValue;
    /**
     * @stable [29.01.2020]
     * @returns {boolean}
     */
    private readonly isQuickSearchEnabled;
    /**
     * @stable [24.01.2020]
     * @returns {number}
     */
    private getMenuWidth;
    /**
     * @stable [11.01.2020]
     * @returns {number}
     */
    private readonly delayTimeout;
    /**
     * @stable [15.01.2020]
     * @returns {boolean}
     */
    private readonly doOptionsExist;
    /**
     * @stable [22.01.2020]
     * @returns {boolean}
     */
    private readonly isMenuRendered;
    /**
     * @stable [28.01.2020]
     * @returns {boolean}
     */
    private readonly isLocalOptionsUsed;
    /**
     * @stable [24.01.2020]
     * @returns {boolean}
     */
    private readonly isMenuAnchored;
    /**
     * @stable [01.02.2020]
     * @returns {boolean}
     */
    private readonly isForceUseLocalFilter;
    /**
     * @stable [31.01.2020]
     * @returns {boolean}
     */
    private readonly isForceReload;
    /**
     * @stable [11.01.2020]
     * @returns {boolean}
     */
    private readonly isMenuAlreadyRenderedAndOpened;
    /**
     * @stable [24.01.2020]
     * @returns {HTMLElement}
     */
    private getMenuAnchorElement;
    /**
     * @stable [30.11.2019]
     * @returns {IMenu}
     */
    private readonly menu;
    /**
     * @stable [30.01.2020]
     * @returns {ISelectOptionEntity}
     */
    private readonly $$cashedValue;
    /**
     * @stable [01.02.2020]
     * @returns {string}
     */
    private readonly dictionary;
    /**
     * @stable [17.02.2020]
     * @returns {TProps}
     */
    private readonly systemBaseSelectProps;
}
