"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var react_text_mask_1 = require("react-text-mask");
var util_1 = require("../../../util");
var definitions_interface_1 = require("../../../definitions.interface");
var field_1 = require("../field");
var progress_1 = require("../../progress");
var keyboard_1 = require("../../keyboard");
var definition_1 = require("../../../definition");
var BaseTextField = /** @class */ (function (_super) {
    __extends(BaseTextField, _super);
    /**
     * @stable [25.02.2019]
     * @param {TProps} props
     */
    function BaseTextField(props) {
        var _this = _super.call(this, props) || this;
        _this.mirrorInputRef = React.createRef();
        _this.keyboardRef = React.createRef();
        _this.onKeyboardChange = _this.onKeyboardChange.bind(_this);
        _this.onDocumentClickHandler = _this.onDocumentClickHandler.bind(_this);
        if (util_1.isClearActionRendered(props)) {
            _this.addClearAction();
        }
        return _this;
    }
    /**
     * @stable [25.02.2019]
     * @returns {JSX.Element}
     */
    BaseTextField.prototype.getInputElement = function () {
        return R.isNil(this.getFieldMask())
            ? _super.prototype.getInputElement.call(this)
            : this.getMaskedInputElement();
    };
    /**
     * @stable [24.10.2019]
     * @returns {string}
     */
    BaseTextField.prototype.getSelfElementClassName = function () {
        return util_1.joinClassName(_super.prototype.getSelfElementClassName.call(this), 'rac-text-field'); // TODO Deprecated rac-text-field
    };
    Object.defineProperty(BaseTextField.prototype, "keyboardElement", {
        /**
         * @stable [03.09.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(keyboard_1.Keyboard, __assign({ ref: this.keyboardRef, field: this, onClose: this.closeVirtualKeyboard, onChange: this.onKeyboardChange }, this.getKeyboardProps())));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [13.01.2019]
     * @returns {boolean}
     */
    BaseTextField.prototype.isKeyboardOpen = function () {
        return _super.prototype.isKeyboardOpen.call(this) || this.isKeyboardInline;
    };
    /**
     * @stable [02.02.2020]
     * @returns {IKeyboardProps}
     */
    BaseTextField.prototype.getKeyboardProps = function () {
        return this.props.keyboardConfiguration || {};
    };
    /**
     * @stable [02.02.2020]
     */
    BaseTextField.prototype.openVirtualKeyboard = function () {
        var _this = this;
        _super.prototype.openVirtualKeyboard.call(this, function () {
            if (!_this.isKeyboardInline) {
                _this.keyboardListenerUnsubscriber = _this.domAccessor.captureEvent({
                    element: _this.environment.document,
                    callback: _this.onDocumentClickHandler,
                    capture: true,
                    eventName: _this.environment.touchedPlatform ? definition_1.TouchEventsEnum.TOUCH_START : definition_1.EventsEnum.MOUSE_DOWN,
                });
            }
        });
    };
    /**
     * @stable [30.10.2019]
     */
    BaseTextField.prototype.onCloseVirtualKeyboard = function () {
        _super.prototype.onCloseVirtualKeyboard.call(this);
        if (util_1.isFn(this.keyboardListenerUnsubscriber)) {
            this.keyboardListenerUnsubscriber();
            this.keyboardListenerUnsubscriber = null;
        }
    };
    /**
     * @stable [04.09.2018]
     */
    BaseTextField.prototype.refreshCaretPosition = function () {
        _super.prototype.refreshCaretPosition.call(this);
        this.input.scrollLeft = this.input.scrollWidth;
    };
    /**
     * @stable [04.09.2018]
     * @returns {number}
     */
    BaseTextField.prototype.getCaretPosition = function () {
        return this.isValuePresent
            ? Math.min(this.jMirrorInput.width(), this.jqInput.width())
            : 0;
    };
    /**
     * @stable [23.10.2019]
     * @returns {string}
     */
    BaseTextField.prototype.getFieldClassName = function () {
        return util_1.joinClassName(_super.prototype.getFieldClassName.call(this), 'rac-base-text');
    };
    Object.defineProperty(BaseTextField.prototype, "progressLabelElement", {
        get: function () {
            return util_1.orNull(this.isFieldBusy(), function () { return React.createElement(progress_1.ProgressLabel, { className: 'rac-field-loader rac-alignment-center' }); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [12.09.2018]
     * @returns {JSX.Element}
     */
    BaseTextField.prototype.getMirrorInputElement = function () {
        if (!this.isKeyboardUsed || !this.isSyntheticCursorUsed || this.isValueNotPresent) {
            return null;
        }
        // TODO Move to support
        var value = this.value;
        var content = String((this.props.type === 'password'
            ? String(value).replace(/./g, this.environment.passwordPlaceholder)
            : value)).replace(/ /g, definitions_interface_1.UniCodesEnum.NO_BREAK_SPACE);
        return (React.createElement("span", { ref: this.mirrorInputRef, className: util_1.joinClassName(this.getInputElementProps().className, 'rac-field-input-mirror', 'rac-invisible') }, content));
    };
    // TODO
    BaseTextField.prototype.getInputCaretElement = function () {
        var _this = this;
        var state = this.state;
        var textOffset = 2;
        return util_1.orNull(this.isSyntheticCursorUsed && this.isKeyboardOpen() && state.caretVisibility && !R.isNil(state.caretPosition), function () { return (React.createElement("div", { className: 'rac-field-input-caret', style: { left: state.caretPosition + util_1.parseValueAtPx(_this.jqInput.css('paddingLeft')) - textOffset } }, "|")); });
    };
    Object.defineProperty(BaseTextField.prototype, "prefixLabelElement", {
        /**
         * @stable [15.09.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            var props = this.props;
            return (util_1.orNull(props.prefixLabel, React.createElement("span", { className: 'rac-field-prefix-label rac-absolute-left-center-position' }, props.prefixLabel)));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [28.10.2019]
     * @param {} action
     * @returns {boolean}
     */
    BaseTextField.prototype.isFieldActionDisabled = function (action) {
        return util_1.calc(action.disabled) || this.isInactive;
    };
    /**
     * @stable [01.12.2019]
     * @returns {IFieldActionEntity[]}
     */
    BaseTextField.prototype.getFieldActions = function () {
        var isValuePresent = this.isValuePresent;
        return _super.prototype.getFieldActions.call(this).filter(function (action) {
            switch (action.type) {
                case definition_1.FieldActionTypesEnum.CLOSE:
                    return isValuePresent;
            }
            return true;
        });
    };
    /**
     * @stable [16.02.2019]
     * @param {IBaseEvent} e
     */
    BaseTextField.prototype.onDocumentClickHandler = function (e) {
        var element = event.target;
        var keyboardEl = this.keyboardRef.current.getSelf();
        if (!keyboardEl) {
            return;
        }
        if (this.domAccessor.getParentsAsElements({ parentClassName: definition_1.KeyboardClassNamesEnum.KEYBOARD, element: element })
            .includes(keyboardEl)) {
            return;
        }
        this.closeVirtualKeyboard();
    };
    /**
     * @stable [04.09.2018]
     * @param {string} rawValue
     */
    BaseTextField.prototype.onKeyboardChange = function (rawValue) {
        // Synthetic event creation to reduce source code
        var syntheticEvent = { target: { value: rawValue } };
        // To handle various field types, NumberField, etc..
        this.onChangeManually(this.getRawValueFromEvent(syntheticEvent));
    };
    Object.defineProperty(BaseTextField.prototype, "jMirrorInput", {
        /**
         * TODO domAccessor
         */
        get: function () {
            return util_1.toJqEl(this.mirrorInputRef.current);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [25.02.2019]
     * @returns {JSX.Element}
     */
    BaseTextField.prototype.getMaskedInputElement = function () {
        var mask = this.getFieldMask();
        var props = this.props;
        return (React.createElement(react_text_mask_1.default, __assign({ guide: util_1.nvl(props.maskGuide, BaseTextField.DEFAULT_MASK_GUIDE), placeholderChar: util_1.nvl(props.maskPlaceholderChar, definitions_interface_1.UniCodesEnum.SPACE), mask: mask }, this.getInputElementProps())));
    };
    Object.defineProperty(BaseTextField.prototype, "actionsElement", {
        /**
         * @stable [28.10.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return (React.createElement(React.Fragment, null, this.getFieldActions().map(function (action) { return _this.uiFactory.makeIcon(__assign({}, action, { key: "field-action-key-" + action.type, disabled: _this.isFieldActionDisabled(action) })); })));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [30.10.2019]
     */
    BaseTextField.prototype.addClearAction = function () {
        var _this = this;
        this.defaultActions.push({
            type: definition_1.FieldActionTypesEnum.CLOSE,
            onClick: function () { return _this.clearValue(); },
            disabled: function () { return _this.isInactive; },
        });
    };
    Object.defineProperty(BaseTextField.prototype, "isKeyboardInline", {
        /**
         * @stable [02.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isInline(this.getKeyboardProps());
        },
        enumerable: true,
        configurable: true
    });
    BaseTextField.DEFAULT_MASK_GUIDE = false;
    return BaseTextField;
}(field_1.Field));
exports.BaseTextField = BaseTextField;
//# sourceMappingURL=base-textfield.component.js.map