import { IEffectsAction } from 'redux-effects-promise';
import { IKeyValue } from '../../definitions.interface';
import { FieldChangeEntityT, IApiEntity } from '../../definition';
export declare class FormActionBuilder {
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildDestroyActionType(section: string): string;
    /**
     * @stable [26.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildClearActionType(section: string): string;
    /**
     * @stable [02.10.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildChangeActionType(section: string): string;
    /**
     * @stable [20.12.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildDefaultChangeActionType(section: string): string;
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildValidActionType(section: string): string;
    /**
     * @stable [14.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildActiveValueActionType(section: string): string;
    /**
     * @stable [02.09.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildDeactivatedValueActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitActionType(section: string): string;
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildProgressActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitDoneActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitFinishedActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitErrorActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildSubmitDoneAction(section: string): IEffectsAction;
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetAction(section: string): IEffectsAction;
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildProgressAction(section: string): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    static buildValidAction(section: string, valid: boolean): IEffectsAction;
    static buildSubmitFinishedAction(section: string): IEffectsAction;
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildDestroyAction(section: string): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    static buildClearPlainAction(section: string, fieldName: string): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    static buildClearAction(section: string, fieldName: string): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    static buildChangesAction<TData extends IKeyValue = IKeyValue>(section: string, changes: TData): IEffectsAction;
    static buildDefaultChangesAction<TData extends IKeyValue = IKeyValue>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    static buildChangesPlainAction<TData extends IKeyValue = IKeyValue>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {FieldChangeEntityT} payload
     * @returns {IEffectsAction}
     */
    static buildChangePlainAction(section: string, payload: FieldChangeEntityT): IEffectsAction;
    /**
     * @stable [11.09.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildResetPlainAction(section: string): IEffectsAction;
    /**
     * @stable [01.03.2020]
     * @param {string} section
     * @param {IApiEntity} apiEntity
     * @returns {IEffectsAction}
     */
    static buildSubmitPlainAction(section: string, apiEntity: IApiEntity): IEffectsAction;
    /***
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    static buildValidPlainAction(section: string, valid: boolean): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {IKeyValue} changes
     * @returns {FieldChangeEntityT}
     */
    private static buildChangesPayload;
}
