"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var util_1 = require("../../util");
var base_component_1 = require("../base/base.component");
var button_1 = require("../button");
var definition_1 = require("../../definition");
var menu_1 = require("../menu");
var link_1 = require("../link");
var Header = /** @class */ (function (_super) {
    __extends(Header, _super);
    /**
     * @stable [06.02.2020]
     * @param {IHeaderProps} props
     */
    function Header(props) {
        var _this = _super.call(this, props) || this;
        _this.defaultMenuProps = {
            options: [
                { label: _this.settings.messages.SETTINGS, icon: definition_1.IconsEnum.SETTINGS, value: definition_1.HeaderUserMenuActionsEnum.PROFILE },
                { label: _this.settings.messages.LOG_OUT, icon: definition_1.IconsEnum.SIGN_OUT_ALT, value: definition_1.HeaderUserMenuActionsEnum.EXIT }
            ],
        };
        _this.defaultMenuActionProps = {
            icon: definition_1.IconsEnum.MORE,
        };
        _this.menuAnchorRef = React.createRef();
        _this.menuRef = React.createRef();
        _this.getMenuAnchorElement = _this.getMenuAnchorElement.bind(_this);
        _this.onMenuActionClick = _this.onMenuActionClick.bind(_this);
        _this.onMenuItemSelect = _this.onMenuItemSelect.bind(_this);
        return _this;
    }
    /**
     * @stable [06.02.2020]
     * @returns {JSX.Element}
     */
    Header.prototype.render = function () {
        var mergedProps = this.mergedProps;
        var user = mergedProps.user;
        var headerContentElement = this.headerContentElement;
        return (React.createElement("div", { className: util_1.joinClassName(definition_1.HeaderClassesEnum.HEADER, util_1.calc(mergedProps.className)) },
            headerContentElement && (React.createElement("div", { className: definition_1.HeaderClassesEnum.HEADER_CONTENT }, headerContentElement)),
            React.createElement("div", { className: definition_1.HeaderClassesEnum.HEADER_ACTIONS },
                this.props.children,
                React.createElement(link_1.Link, { to: this.routes.profile, className: definition_1.HeaderClassesEnum.HEADER_USER_AVATAR, style: { backgroundImage: this.domAccessor.asImageUrl(user.url || this.settings.urls.emptyAvatar) } }),
                React.createElement(link_1.Link, { to: this.routes.profile, className: definition_1.HeaderClassesEnum.HEADER_USER_INFO }, user.name),
                this.menuActionElement)));
    };
    Object.defineProperty(Header.prototype, "headerContentElement", {
        /**
         * @stable [24.03.2020]
         * @returns {React.ReactNode}
         */
        get: function () {
            var _a = this.mergedProps.backActionConfiguration, backActionConfiguration = _a === void 0 ? {} : _a;
            var contentElement = this.contentElement;
            if (this.isBackActionRendered) {
                return (React.createElement(React.Fragment, null,
                    React.createElement(button_1.Button, __assign({ icon: definition_1.IconsEnum.BACK2 }, backActionConfiguration, { className: util_1.joinClassName(definition_1.HeaderClassesEnum.HEADER_BACK_ACTION, util_1.calc(backActionConfiguration.className)) })),
                    contentElement));
            }
            return contentElement;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Header.prototype, "menuActionElement", {
        /**
         * @stable [06.02.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _a = this.mergedProps, _b = _a.menuActionConfiguration, menuActionConfiguration = _b === void 0 ? {} : _b, menuConfiguration = _a.menuConfiguration;
            return (React.createElement(React.Fragment, null,
                React.createElement(button_1.Button, __assign({ ref: this.menuAnchorRef }, this.defaultMenuActionProps, menuActionConfiguration, { className: util_1.joinClassName(definition_1.HeaderClassesEnum.HEADER_MENU_ACTION, util_1.calc(menuActionConfiguration.className)), onClick: this.onMenuActionClick })),
                React.createElement(menu_1.Menu, __assign({ ref: this.menuRef }, this.defaultMenuProps, menuConfiguration, { anchorElement: this.getMenuAnchorElement, positionConfiguration: definition_1.DEFAULT_DOM_RIGHT_POSITION_CONFIG_ENTITY, onSelect: this.onMenuItemSelect }))));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [24.03.2020]
     * @param {IMenuItemEntity} menuItem
     */
    Header.prototype.onMenuItemSelect = function (menuItem) {
        util_1.ifNotNilThanValue(this.mergedProps.onSelect, function (onSelect) { return onSelect(menuItem); });
    };
    /**
     * @stable [06.02.2020]
     */
    Header.prototype.onMenuActionClick = function () {
        this.menuRef.current.show();
    };
    /**
     * @stable [06.02.2020]
     * @returns {HTMLElement}
     */
    Header.prototype.getMenuAnchorElement = function () {
        return this.menuAnchorRef.current.getSelf();
    };
    Object.defineProperty(Header.prototype, "contentElement", {
        /**
         * @stable [24.03.2020]
         * @returns {React.ReactNode}
         */
        get: function () {
            return util_1.calc(this.mergedProps.content, this);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Header.prototype, "isBackActionRendered", {
        /**
         * @stable [12.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isBackActionRendered(this.mergedProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Header.prototype, "mergedProps", {
        /**
         * @stable [24.03.2020]
         * @returns {IHeaderProps}
         */
        get: function () {
            return util_1.mergeWithSystemProps(this.props, this.settings.components.header);
        },
        enumerable: true,
        configurable: true
    });
    return Header;
}(base_component_1.BaseComponent));
exports.Header = Header;
//# sourceMappingURL=header.component.js.map