"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var link_1 = require("../../link");
var menu_1 = require("../../menu");
var definition_1 = require("../../../definition");
var base_component_1 = require("../../base/base.component");
var NavigationList = /** @class */ (function (_super) {
    __extends(NavigationList, _super);
    /**
     * @stable [23.03.2020]
     * @param {INavigationListProps} props
     */
    function NavigationList(props) {
        var _this = _super.call(this, props) || this;
        _this.menuRef = React.createRef();
        _this.itemsRefsMap = new Map();
        _this.asPopupMenuAnchorElement = _this.asPopupMenuAnchorElement.bind(_this);
        _this.onPopupMenuItemSelect = _this.onPopupMenuItemSelect.bind(_this);
        _this.state = {};
        return _this;
    }
    /**
     * @stable [24.10.2019]
     * @returns {JSX.Element}
     */
    NavigationList.prototype.render = function () {
        var _this = this;
        this.itemsRefsMap.clear();
        var items = this.props.items;
        return (React.createElement("nav", { ref: this.selfRef, className: 'rac-navigation-list' },
            this.getListDividerElement(),
            items.map(this.toElement, this),
            util_1.ifNotNilThanValue(this.state.activeGroup, function (activeGroup) { return (React.createElement(menu_1.Menu, { positionConfiguration: {
                    collision: 'fit',
                    my: 'left top',
                    at: 'right top',
                }, heightRestricted: false, ref: _this.menuRef, options: util_1.notNilValuesArrayFilter.apply(void 0, items.map(function (item) { return _this.asPopupMenuItem(item, activeGroup); })).map(function (itm) { return ({ value: _this.asUniqueKey(itm.link, 'link'), label: _this.t(itm.label), rawData: itm }); }), anchorElement: _this.asPopupMenuAnchorElement, onSelect: _this.onPopupMenuItemSelect })); })));
    };
    /**
     * @stable [23.03.2020]
     */
    NavigationList.prototype.componentWillUnmount = function () {
        this.itemsRefsMap.clear();
        _super.prototype.componentWillUnmount.call(this);
    };
    /**
     * @stable [07.02.2020]
     * @param {string} key
     * @returns {JSX.Element}
     */
    NavigationList.prototype.getListDividerElement = function (key) {
        return (React.createElement("div", { key: key, className: 'rac-list-divider' }));
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemEntity} item
     * @returns {JSX.Element}
     */
    NavigationList.prototype.toElement = function (item) {
        var _this = this;
        var isExpanded = this.isItemExpanded(item);
        var fullLayoutModeEnabled = this.isFullLayoutModeEnabled;
        var label = this.t(item.label);
        switch (item.type) {
            case definition_1.NavigationItemTypesEnum.SUB_HEADER:
                var isGroupItemActive = !isExpanded && this.hasActiveChild(item);
                var groupRef = React.createRef();
                this.itemsRefsMap.set(item.value, groupRef);
                var ind = this.props.items.length - 1 -
                    this.props.items.slice().reverse().findIndex(function (itm) { return itm.type === definition_1.NavigationItemTypesEnum.SUB_HEADER; });
                return (React.createElement("div", { ref: groupRef, key: this.asUniqueKey(item.label, 'label'), className: util_1.joinClassName(this.asItemClasses(true, isGroupItemActive, isExpanded), ind === this.props.items.lastIndexOf(item) && !isExpanded && 'rac-navigation-list__last-section'), title: label, onClick: function () { return _this.onGroupClick(item); } },
                    this.uiFactory.makeIcon({
                        type: item.icon || 'list',
                    }),
                    fullLayoutModeEnabled && label,
                    fullLayoutModeEnabled && this.uiFactory.makeIcon({
                        type: isExpanded ? 'dropdown-opened' : 'dropdown',
                        className: 'rac-navigation-list__expand-icon',
                    })));
            case definition_1.NavigationItemTypesEnum.DIVIDER:
                return util_1.ifNotFalseThanValue(this.props.dividerRendered, function () { return _this.getListDividerElement(R.isNil(item.parent)
                    ? util_1.uuid()
                    : _this.asUniqueKey(item.parent.label, 'divider')); });
            default:
                var isGroup = R.isNil(item.parent);
                return util_1.orNull(isGroup || fullLayoutModeEnabled && isExpanded, function () { return _this.asItemElement(item); });
        }
    };
    /**
     * @stable [12.02.2020]
     * @param {INavigationListItemEntity} item
     * @returns {JSX.Element}
     */
    NavigationList.prototype.asItemElement = function (item) {
        var isFullLayoutModeEnabled = this.isFullLayoutModeEnabled;
        var label = this.t(item.label);
        var isGroup = R.isNil(item.parent);
        var isExpanded = this.isItemExpanded(item);
        return (React.createElement(link_1.Link, { to: item.link, key: this.asUniqueKey(item.link, 'link'), className: this.asItemClasses(isGroup, item.active, isExpanded), title: label },
            this.uiFactory.makeIcon({
                type: item.icon,
                className: definition_1.NavigationListClassesEnum.NAVIGATION_LIST_ITEM_ICON,
            }),
            isFullLayoutModeEnabled && label));
    };
    /**
     * @stable [23.03.2020]
     * @param {IMenuItemEntity<INavigationListItemEntity>} option
     */
    NavigationList.prototype.onPopupMenuItemSelect = function (option) {
        var _this = this;
        this.setState({ activeGroup: null }, function () {
            return util_1.ifNotNilThanValue(_this.props.onClick, function (onClick) { return onClick(option.rawData); });
        });
    };
    /**
     * @stable [24.03.2020]
     * @param {INavigationListItemEntity} entity
     */
    NavigationList.prototype.onGroupClick = function (entity) {
        var _this = this;
        util_1.ifNotNilThanValue(this.props.onGroupClick, function (onGroupClick) { return onGroupClick(entity); });
        if (!this.isFullLayoutModeEnabled) {
            this.setState({ activeGroup: entity }, function () { return _this.menuRef.current.show(); });
        }
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemEntity} item
     * @returns {boolean}
     */
    NavigationList.prototype.isItemExpanded = function (item) {
        var expandedGroups = this.props.expandedGroups;
        return expandedGroups[item.value] === true
            || (!R.isNil(item.parent) && expandedGroups[item.parent.value] === true);
    };
    Object.defineProperty(NavigationList.prototype, "isFullLayoutModeEnabled", {
        /**
         * @stable [23.09.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.layoutMode === definition_1.LayoutModesEnum.FULL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationList.prototype, "layoutMode", {
        // TODO
        get: function () {
            return util_1.nvl(this.systemLayoutMode, this.props.mode);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationList.prototype, "systemLayoutMode", {
        /**
         * @stable [04.02.2020]
         * @returns {LayoutModesEnum}
         */
        get: function () {
            return this.systemSettings.layoutMode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationList.prototype, "systemSettings", {
        /**
         * @stable [04.02.2020]
         * @returns {IDefaultLayoutProps}
         */
        get: function () {
            var _a = (this.settings.components || {}).defaultLayout, defaultLayout = _a === void 0 ? {} : _a;
            return defaultLayout;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemEntity} item
     * @returns {boolean}
     */
    NavigationList.prototype.hasActiveChild = function (item) {
        var activeItem = R.find(function (itm) { return !!itm.active; }, this.props.items);
        return !R.isNil(activeItem) && !R.isNil(R.find(function (child) { return child.link === activeItem.link; }, item.children || []));
    };
    /**
     * @stable [24.03.2020]
     * @param {INavigationListItemEntity} item
     * @param {INavigationListItemEntity} activeGroup
     * @returns {INavigationListItemEntity}
     */
    NavigationList.prototype.asPopupMenuItem = function (item, activeGroup) {
        if (definition_1.NAVIGATION_EXTRA_ITEM_TYPES.includes(item.type)) {
            return null;
        }
        return util_1.ifNotNilThanValue(item.parent, function (parent) { return util_1.orNull(parent.value === activeGroup.value, item); });
    };
    /**
     * @stable [24.03.2020]
     * @returns {HTMLElement}
     */
    NavigationList.prototype.asPopupMenuAnchorElement = function () {
        return this.itemsRefsMap.get(this.state.activeGroup.value).current;
    };
    /**
     * @stable [23.03.2020]
     * @param {boolean} isGroup
     * @param {boolean} isActive
     * @param {boolean} isExpanded
     * @returns {string}
     */
    NavigationList.prototype.asItemClasses = function (isGroup, isActive, isExpanded) {
        return (util_1.joinClassName(definition_1.NavigationListClassesEnum.NAVIGATION_LIST_SECTION, isGroup
            ? definition_1.NavigationListClassesEnum.NAVIGATION_LIST_GROUP_SECTION
            : definition_1.NavigationListClassesEnum.NAVIGATION_LIST_ITEM_SECTION, isActive
            ? definition_1.NavigationListClassesEnum.NAVIGATION_LIST_ACTIVE_SECTION
            : (isExpanded ? definition_1.NavigationListClassesEnum.NAVIGATION_LIST_EXPANDED_SECTION : '')));
    };
    /**
     * @stable [23.03.2020]
     * @param {string} link
     * @param {string} prefix
     * @returns {string}
     */
    NavigationList.prototype.asUniqueKey = function (link, prefix) {
        return "navigation-list-key-" + link + "-" + prefix;
    };
    return NavigationList;
}(base_component_1.BaseComponent));
exports.NavigationList = NavigationList;
//# sourceMappingURL=navigation-list.component.js.map