"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../util");
var universal_component_1 = require("../base/universal.component");
var UniversalList = /** @class */ (function (_super) {
    __extends(UniversalList, _super);
    function UniversalList() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [21.06.2018]
     * @returns {JSX.Element}
     */
    UniversalList.prototype.render = function () {
        var props = this.props;
        if (this.originalDataSourceDoesNotExist
            || this.emptyData
            || props.progress
            || props.error) {
            return this.getMessage();
        }
        return this.getView();
    };
    /**
     * @stable [23.10.2019]
     * @param {IEntity} entity
     * @returns {boolean}
     */
    UniversalList.prototype.isEntitySelected = function (entity) {
        return util_1.SAME_ENTITY_PREDICATE(this.props.selected, entity);
    };
    /**
     * @stable [19.08.2018]
     * @param {IEntity} entity
     * @returns {string}
     */
    UniversalList.prototype.toRowKey = function (entity) {
        return "data-row-" + (R.isNil(entity.id) ? util_1.uuid() : entity.id); // Infinity scroll supporting
    };
    Object.defineProperty(UniversalList.prototype, "originalDataSource", {
        /**
         * @stable [17.06.2018]
         * @returns {IEntity[]}
         */
        get: function () {
            return this.props.data;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "dataSource", {
        /**
         * @stable [17.06.2018]
         * @returns {IEntity[]}
         */
        get: function () {
            var filteredAndSortedEntities = util_1.filterAndSortEntities(this.filterAndSortOriginalDataSourceUsingLocalFiltersAndSorters(), this.props);
            var toNumber = this.toNumber;
            var pagedData;
            return R.isNil(toNumber)
                // Remote and local pagination are supported simultaneously.
                // The length result is equal to zero in a remote pagination case
                || (pagedData = filteredAndSortedEntities.slice(this.fromNumber, toNumber)).length === 0
                ? filteredAndSortedEntities
                : pagedData;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [09.06.2018]
     * @returns {TMessageComponentProps}
     */
    UniversalList.prototype.getMessageComponentProps = function () {
        var props = this.props;
        return {
            error: props.error,
            progress: props.progress,
            emptyData: this.emptyData,
            emptyMessage: this.emptyMessage,
            emptyDataMessage: props.emptyDataMessage,
            errorMessage: props.error,
        };
    };
    /**
     * @stable [06.06.2018]
     * @returns {IEntity[]}
     */
    UniversalList.prototype.filterAndSortOriginalDataSourceUsingLocalFiltersAndSorters = function () {
        return this.originalDataSource;
    };
    Object.defineProperty(UniversalList.prototype, "isRemoteMode", {
        /**
         * @stable [18.10.2018]
         * @returns {boolean}
         */
        get: function () {
            return !this.props.localFiltration;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "emptyMessage", {
        /**
         * @stable [09.06.2018]
         * @returns {React.ReactNode}
         */
        get: function () {
            return this.props.emptyMessage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "emptyData", {
        /**
         * @stable [17.06.2018]
         * @returns {boolean}
         */
        get: function () {
            if (this.originalDataSourceDoesNotExist) {
                return false; // It's important to show the difference between the conditions: length === 0 and data === null!
            }
            var dataSource = this.isRemoteMode
                ? this.dataSource
                : this.originalDataSource; // In the case of a local filtering we need to get a false result
            return Array.isArray(dataSource) && dataSource.length === 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "originalDataSourceDoesNotExist", {
        /**
         * @stable [17.06.2018]
         * @returns {boolean}
         */
        get: function () {
            return R.isNil(this.originalDataSource);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "fromNumber", {
        /**
         * @stable [09.05.2018]
         * @returns {number}
         */
        get: function () {
            return util_1.pageFromNumber(this.props) - 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UniversalList.prototype, "toNumber", {
        /**
         * @stable [09.05.2018]
         * @returns {number}
         */
        get: function () {
            return util_1.pageToNumber(this.props);
        },
        enumerable: true,
        configurable: true
    });
    return UniversalList;
}(universal_component_1.UniversalComponent));
exports.UniversalList = UniversalList;
//# sourceMappingURL=universal-list.component.js.map