import * as moment from 'moment';
import 'moment-timezone';
import { IKeyValue } from '../../definitions.interface';
import { IDateConverter } from './date-converter.interface';
import { DateTimeLikeTypeT, ICalendarConfigEntity, ICalendarEntity, IDateTimeConfigEntity, IDayOfYearEntity, IFromToDayOfYearEntity, IMinMaxDatesRangeConfigEntity, IPersonAgeConfigEntity, MomentT } from '../../definition';
export declare class DateConverter implements IDateConverter<MomentT> {
    private static WEEKDAYS_SHORT;
    private static WEEKDAYS;
    private static DEFAULT_SHORTEST_ISO_WEEKDAYS;
    private static DEFAULT_SHORTEST_WEEKDAYS;
    private readonly environment;
    private readonly settings;
    private readonly appOnlineStartingDate;
    /**
     * @stable [22.01.2020]
     */
    constructor();
    /**
     * @stable [22.01.2020]
     * @returns {number}
     */
    readonly appOnlineLifeTimeInSeconds: number;
    /**
     * @stable [22.01.2020]
     * @returns {number}
     */
    readonly appOnlineLifeTimeInHours: number;
    /**
     * @stable [08.01.2020]
     * @param {DateTimeLikeTypeT} date1
     * @param {DateTimeLikeTypeT} date2
     * @returns {number}
     */
    compare(date1: DateTimeLikeTypeT, date2: DateTimeLikeTypeT): number;
    /**
     * @deprecated
     */
    format(date: DateTimeLikeTypeT, inputFormat: string, outputFormat: string): string;
    /**
     * @stable [26.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    dateAsString(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asStartUnitOf(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [07.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {IDayOfYearEntity}
     */
    asDayOfYearEntity(cfg?: IDateTimeConfigEntity): IDayOfYearEntity;
    /**
     * @stable [03.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asEndUnitOf(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asFirstDayOfWeek(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asFirstDayOfMonth(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asFirstDayOfQuarter(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asFirstDayOfYear(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asFirstDayOfWeekAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [06.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asFirstDayOfMonthAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asFirstDayOfQuarterAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [21.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asFirstDayOfYearAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asLastDayOfQuarter(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asLastDayOfQuarterAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asLastDayOfMonth(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asLastDayOfMonthAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asLastDayOfWeek(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asLastDayOfWeekAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asLastDayOfYear(cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asLastDayOfYearAsDate(cfg?: IDateTimeConfigEntity): Date;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    addDuration(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [06.01.2020]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {number}
     */
    asAbsoluteDayOfYear(cfg?: IDateTimeConfigEntity): number;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {moment.Moment}
     */
    addDays(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    addDaysAsDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @stable [03.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    addMonths(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [06.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    addMonthsAsDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @stable [06.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    addQuartersAsDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    addQuarters(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    addYears(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [08.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    addYearsAsDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    addWeeks(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [07.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    addWeeksAsDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    addDaysToUiDate(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [02.01.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    addDaysToUiDateAsDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @deprecated
     */
    fromDateTimeToArbitraryFormat(date: DateTimeLikeTypeT, outputFormat: string): string;
    /**
     * @stable [04.03.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} outputFormat
     * @returns {string}
     */
    fromDateToArbitraryFormat(date: DateTimeLikeTypeT, outputFormat: string): string;
    /**
     * @stable [09.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    dateAsPstDateString(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [09.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    dateAsPstTimeString(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    fromDateTimeToPstTime(cfg: IDateTimeConfigEntity): string;
    /**
     * @deprecated
     */
    fromDateTimeToDate(date: DateTimeLikeTypeT): string;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    dateAsDateTimeString(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [05.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    dateAsDateString(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [26.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    dateAsUiDateString(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [25.12.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    fromDateTimeToUiDateTime(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: 2018-04-07T20:54:45+03:00]
     * @returns {string} [Example: 20:54:45]
     */
    fromDateTimeToTime(date: DateTimeLikeTypeT): string;
    /**
     * @deptecated
     */
    fromDateTimeToDateTime(date: DateTimeLikeTypeT): string;
    /**
     * @stable [25.12.2019]
     * @tested
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    fromUiDateTimeToDateTime(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    fromUiDateToDateTime(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [09.11.2018]
     * @param {TEntity} entity
     * @param {string} dateFieldName
     * @param {string} timeFieldName
     * @param {(entity: TEntity) => string} dateResolver
     * @returns {IKeyValue}
     */
    splitToDateTimeFields<TEntity>(entity: TEntity, dateFieldName: string, timeFieldName: string, dateResolver: (entity: TEntity) => string): IKeyValue;
    /**
     * @deprecated
     */
    tryConvertToDate(date: DateTimeLikeTypeT, inputFormat?: string): DateTimeLikeTypeT;
    /**
     * @stable [06.06.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {number}
     */
    tryConvertToDateAsTime(date: DateTimeLikeTypeT, inputFormat?: string): number;
    /**
     * @deprecated
     */
    tryAddXDurationAsMomentDate(unit: moment.DurationInputArg2, duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [11.08.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {number}
     */
    tryGetWeekdayNumber(date?: DateTimeLikeTypeT, inputFormat?: string): number;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg2} unit
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXDuration(unit: moment.DurationInputArg2, duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXDays(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [07.01.2020]
     * @param {Date} date
     * @returns {Date}
     */
    asDayOfYear(date?: Date): Date;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXMonths(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [10.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXQuarters(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [10.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXYears(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [09.02.2019]
     * @param {moment.DurationInputArg2} unit
     * @param {moment.unitOfTime.StartOf} startOf
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryGetFirstDayOfXAsMomentDate(unit: moment.DurationInputArg2, startOf: moment.unitOfTime.StartOf, duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [08.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryGetFirstDayOfMonthAsMomentDate(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [10.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryGetFirstDayOfQuarterAsMomentDate(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [09.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryGetFirstDayOfWeekAsMomentDate(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [09.02.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryGetFirstDayOfWeek(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [08.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryGetFirstDayOfMonth(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [08.08.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {boolean}
     */
    isDateBelongsToCurrentWeek(date: DateTimeLikeTypeT, inputFormat?: string): boolean;
    /**
     * @stable [26.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    fromDateToUiDate(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [26.03.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    fromDateTimeToUiDate(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [08.01.2020]
     * @param {IDayOfYearEntity} entity
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    fromDayOfYearEntity(entity: IDayOfYearEntity, cfg?: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [08.01.2020]
     * @param {IDayOfYearEntity} entity
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    fromDayOfYearEntityAsDate(entity: IDayOfYearEntity, cfg?: IDateTimeConfigEntity): Date;
    /**
     * @deprecated
     */
    get30DaysAgo(): Date;
    /**
     * @deprecated
     */
    getXDaysAgo(days: number): Date;
    /**
     * @stable [25.12.2019]
     * @tested
     * @returns {Date}
     */
    getCurrentDate(): Date;
    /**
     * @stable [26.03.2020]
     * @returns {string}
     */
    currentDateAsUiDateString(cfg?: IDateTimeConfigEntity): string;
    getLocalizedWeekday(index: number): string;
    getLocalizedWeekdayShort(index: number): string;
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string[]}
     */
    getShortestWeekdays(cfg?: IDateTimeConfigEntity): string[];
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string[]}
     */
    getLocalizedShortestWeekdays(cfg?: IDateTimeConfigEntity): string[];
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    getShortestWeekday(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [04.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {string}
     */
    getLocalizedShortestWeekday(cfg: IDateTimeConfigEntity): string;
    /**
     * @stable [25.08.2018]
     * @param {number} monthsAgo
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {Date}
     */
    getLastDayOfMonth(monthsAgo?: number, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [25.08.2018]
     * @param {number} monthsAgo
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {Date}
     */
    getFirstDayOfMonth(monthsAgo?: number, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [22.01.2020]
     * @param {IPersonAgeConfigEntity} cfg
     * @returns {number}
     */
    asPersonAge(cfg: IPersonAgeConfigEntity): number;
    isSameMonth(date1: Date, date2: Date): boolean;
    isSameDay(date1: Date, date2: Date): boolean;
    isWeekend(day: number): boolean;
    /**
     * @stable [24.11.2018]
     * @param {string} dateAsString
     * @param {string} timeAsString
     * @returns {string}
     */
    combine(dateAsString: string, timeAsString: string): string;
    /**
     * @stable [03.04.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {Date}
     */
    toDate(date: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @deprecated Use asMomentDate
     */
    toMomentDate(date: DateTimeLikeTypeT, inputFormat?: string, strict?: boolean): moment.Moment;
    /**
     * @stable [02.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {MomentT}
     */
    asMomentDate(cfg: IDateTimeConfigEntity): MomentT;
    /**
     * @stable [07.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {Date}
     */
    asDate(cfg: IDateTimeConfigEntity): Date;
    /**
     * @stable [07.01.2020]
     * @tested
     * @param {IDayOfYearEntity} o1
     * @param {IDayOfYearEntity} o2
     * @returns {number}
     */
    compareDayOfYearEntity(o1: IDayOfYearEntity, o2: IDayOfYearEntity): number;
    /**
     * @stable [07.01.2020]
     * @tested
     * @param {IFromToDayOfYearEntity} range
     * @param {IDayOfYearEntity} entity
     * @returns {IFromToDayOfYearEntity}
     */
    selectDaysOfYearRange(range: IFromToDayOfYearEntity, entity: IDayOfYearEntity): IFromToDayOfYearEntity;
    /**
     * @stable [08.01.2020]
     * @param {IMinMaxDatesRangeConfigEntity} cfg
     * @returns {boolean}
     */
    isDateBelongToDatesRange(cfg: IMinMaxDatesRangeConfigEntity): boolean;
    /**
     * @stable [07.01.2020]
     * @tested
     * @param {IFromToDayOfYearEntity} range
     * @param {IDayOfYearEntity} entity
     * @returns {boolean}
     */
    isDayOfYearBelongToDaysOfYearRange(range: IFromToDayOfYearEntity, entity: IDayOfYearEntity): boolean;
    /**
     * @stable [07.03.2020]
     * @param {IDayOfYearEntity} entity1
     * @param {IDayOfYearEntity} entity2
     * @returns {boolean}
     */
    isDayOfYearEqualOtherDayOfYear(entity1: IDayOfYearEntity, entity2: IDayOfYearEntity): boolean;
    /**
     * @stable [03.01.2020]
     * @param {IDateTimeConfigEntity} cfg
     * @returns {ICalendarEntity}
     */
    asCalendar(cfg?: ICalendarConfigEntity): ICalendarEntity;
    /**
     * @stable [03.01.2019]
     * @param {IDateTimeConfigEntity} cfg
     * @param {(date: MomentT) => TResult} handler
     * @returns {TResult}
     */
    private processValidMomentDate;
    /**
     * @deprecated
     */
    private getCurrentMomentDate;
    /**
     * @stable [11.08.2018]
     * @returns {string}
     */
    private readonly timeZone;
    /**
     * @stable [25.12.2019]
     * @returns {Date}
     */
    private readonly currentDate;
    private readonly dateTimeFormat;
    private readonly dateFormat;
    private readonly timeFormat;
    private readonly uiDateFormat;
    /**
     * @stable [25.12.2019]
     * @returns {string}
     */
    private readonly uiTimeFormat;
    /**
     * @stable [25.12.2019]
     * @returns {string}
     */
    private readonly uiDefaultTime;
    /**
     * @stable [02.01.2019]
     * @returns {string}
     */
    private readonly pstTimeFormat;
    private readonly pstDateFormat;
    private readonly dateTimeSettings;
}
