"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var inversify_1 = require("inversify");
var ts_smart_logger_1 = require("ts-smart-logger");
var definition_1 = require("../../definition");
var util_1 = require("../../util");
var di_1 = require("../../di");
var FieldConverter = /** @class */ (function () {
    /**
     * @stable [09.01.2020]
     */
    function FieldConverter() {
        this.converters = new Map();
        this.placeEntityAsDisplayValue = this.placeEntityAsDisplayValue.bind(this);
        this.selectOptionEntityAsDisplayValue = this.selectOptionEntityAsDisplayValue.bind(this);
        this.selectOptionEntityAsId = this.selectOptionEntityAsId.bind(this);
        this.zipCodeEntityAsDisplayValue = this.zipCodeEntityAsDisplayValue.bind(this);
        this.register({
            from: definition_1.FieldConverterTypesEnum.GEO_CODER_RESULT,
            to: definition_1.FieldConverterTypesEnum.PLACE_ENTITY,
            converter: util_1.asPlaceEntity,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.PLACE_ENTITY,
            to: definition_1.FieldConverterTypesEnum.DISPLAY_VALUE,
            converter: this.placeEntityAsDisplayValue,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.ZIP_CODE_ENTITY,
            to: definition_1.FieldConverterTypesEnum.DISPLAY_VALUE,
            converter: this.zipCodeEntityAsDisplayValue,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.PLACE_ENTITY,
            to: definition_1.FieldConverterTypesEnum.PLACE_PARAMETER,
            converter: this.placeEntityAsDisplayValue,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.SELECT_OPTION_ENTITY,
            to: definition_1.FieldConverterTypesEnum.DISPLAY_VALUE,
            converter: this.selectOptionEntityAsDisplayValue,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.SELECT_OPTION_ENTITY,
            to: definition_1.FieldConverterTypesEnum.ID,
            converter: this.selectOptionEntityAsId,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.DATES_RANGE_ENTITY,
            to: definition_1.FieldConverterTypesEnum.DATES_RANGE_VALUE,
            converter: this.datesRangeEntityAsDatesRangeValue,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.DATES_RANGE_VALUE,
            to: definition_1.FieldConverterTypesEnum.DATES_RANGE_ENTITY,
            converter: this.datesRangeValueAsDatesRangeEntity,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.OAUTH_JWT_DECODED_INFO,
            to: definition_1.FieldConverterTypesEnum.USER_ENTITY,
            converter: this.$fromOAuthJwtDecodedInfoToUserEntity.bind(this),
        });
    }
    FieldConverter_1 = FieldConverter;
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     */
    FieldConverter.prototype.register = function (config) {
        this.converters.set(this.asKey(config), config.converter);
        FieldConverter_1.logger.debug("[$FieldConverter][register] The converter has been registered successfully:", config);
    };
    /**
     * @stable [24.12.2019]
     * @param {IPhoneConfigEntity<libphonenumber.PhoneNumberFormat>} config
     * @returns {string}
     */
    FieldConverter.prototype.convert = function (config) {
        var value = config.value;
        var converter = this.converter(config);
        if (!util_1.isFn(converter)) {
            throw new Error("The converter is not registered! A config " + JSON.stringify(config) + ":");
        }
        return converter(value);
    };
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {(value: AnyT) => AnyT}
     */
    FieldConverter.prototype.converter = function (config) {
        return this.converters.get(this.asKey(config));
    };
    /**
     * @stable [14.03.2020]
     * @param {TValue} value
     * @returns {IUserEntity}
     */
    FieldConverter.prototype.fromOAuthJwtDecodedInfoToUserEntity = function (value) {
        return this.convert({
            from: definition_1.FieldConverterTypesEnum.OAUTH_JWT_DECODED_INFO,
            to: definition_1.FieldConverterTypesEnum.USER_ENTITY,
            value: value,
        });
    };
    /**
     * @stable [28.01.2020]
     * @param {IPlaceEntity | string} placeEntity
     * @returns {string}
     */
    FieldConverter.prototype.placeEntityAsDisplayValue = function (placeEntity) {
        if (R.isNil(placeEntity)) {
            return placeEntity;
        }
        if (util_1.isPrimitive(placeEntity)) {
            return placeEntity;
        }
        var placeEntityAsObject = placeEntity;
        return util_1.join(util_1.notEmptyValuesArrayFilter.apply(void 0, [
            (placeEntityAsObject.streetNumber || '') + " " + (placeEntityAsObject.street || ''),
            placeEntityAsObject.city,
            placeEntityAsObject.region,
            placeEntityAsObject.country
        ].map(function (v) { return (v || '').trim(); })), ', ') || placeEntityAsObject.formattedName || definition_1.FIELD_DISPLAY_EMPTY_VALUE;
    };
    /**
     * @stable [28.01.2020]
     * @param {IPlaceEntity | string} placeEntity
     * @returns {string}
     */
    FieldConverter.prototype.zipCodeEntityAsDisplayValue = function (placeEntity) {
        if (R.isNil(placeEntity)) {
            return placeEntity;
        }
        if (util_1.isPrimitive(placeEntity)) {
            return placeEntity;
        }
        var placeEntityAsObject = placeEntity;
        return placeEntityAsObject.zipCode || definition_1.FIELD_DISPLAY_EMPTY_VALUE;
    };
    /**
     * @stable [28.01.2020]
     * @param {ISelectOptionEntity | StringNumberT} option
     * @returns {StringNumberT}
     */
    FieldConverter.prototype.selectOptionEntityAsDisplayValue = function (option) {
        if (R.isNil(option)) {
            return option;
        }
        if (util_1.isPrimitive(option)) {
            return option;
        }
        var optionAsObject = option;
        return R.isNil(optionAsObject.label)
            ? optionAsObject.value
            : this.t(optionAsObject.label, option);
    };
    /**
     * @stable [28.01.2020]
     * @param {ISelectOptionEntity | StringNumberT} option
     * @returns {EntityIdT}
     */
    FieldConverter.prototype.selectOptionEntityAsId = function (option) {
        if (R.isNil(option)) {
            return option;
        }
        if (util_1.isPrimitive(option)) {
            return option;
        }
        var optionAsObject = option;
        return optionAsObject.value;
    };
    /**
     * @stable [07.03.2020]
     * @param {IDatesRangeEntity} entity
     * @returns {DatesRangeValueT}
     */
    FieldConverter.prototype.datesRangeEntityAsDatesRangeValue = function (entity) {
        if (R.isNil(entity)) {
            return entity;
        }
        return util_1.notNilValuesArrayFilter(entity.from, entity.to, entity.periodMode);
    };
    /**
     * @stable [07.03.2020]
     * @param {DatesRangeValueT} value
     * @returns {IDatesRangeEntity}
     */
    FieldConverter.prototype.datesRangeValueAsDatesRangeEntity = function (value) {
        if (R.isNil(value)) {
            return value;
        }
        return {
            from: value[0],
            to: value[1],
            periodMode: value[2],
        };
    };
    /**
     * @stable [14.03.2020]
     * @param {TValue} value
     * @returns {IUserEntity}
     */
    FieldConverter.prototype.$fromOAuthJwtDecodedInfoToUserEntity = function (value) {
        return { id: -1, name: 'Anonymous' };
    };
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {string}
     */
    FieldConverter.prototype.asKey = function (config) {
        return config.from + "-" + config.to;
    };
    var FieldConverter_1;
    FieldConverter.logger = ts_smart_logger_1.LoggerFactory.makeLogger('FieldConverter');
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Translate),
        __metadata("design:type", Function)
    ], FieldConverter.prototype, "t", void 0);
    FieldConverter = FieldConverter_1 = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], FieldConverter);
    return FieldConverter;
}());
exports.FieldConverter = FieldConverter;
//# sourceMappingURL=field-converter.service.js.map