import * as moment from 'moment';
import { IBirthdayWrapper, ICurrentWrapper, IDateWrapper, IDaysLabelsWrapper, IDaysWrapper, IDayWrapper, IDurationWrapper, IEntityIdTWrapper, IFromToEntity, IIndexWrapper, IInputFormatWrapper, IInputTimeFormatWrapper, IIsoWeekWrapper, IMaxDateWrapper, IMinDateWrapper, IMonthWrapper, INextWrapper, IOutputFormatWrapper, IOutputTimeFormatWrapper, IPeriodModeWrapper, IPeriodTypeWrapper, IPreviousWrapper, IStrictWrapper, ITimeWrapper, ITodayWrapper, IUnitWrapper, IYearWrapper, IZoneWrapper, StringNumberT } from '../definitions.interface';
/**
 * @stable [22.12.2019]
 */
export declare type DateTimeLikeTypeT = string | Date;
export declare type MomentT = moment.Moment;
/**
 * @stable [06.03.2020]
 */
export declare enum DatePeriodsEnum {
    CUSTOM = 0,
    DAY = 1,
    MONTH = 2,
    PREVIOUS_DAY = 3,
    PREVIOUS_MONTH = 4,
    PREVIOUS_QUARTER = 5,
    PREVIOUS_WEEK = 6,
    QUARTER = 7,
    WEEK = 8
}
/**
 * @stable [25.03.2020]
 */
export declare const DAYS_PERIODS: DatePeriodsEnum[];
export declare const WEEKS_PERIODS: DatePeriodsEnum[];
export declare const MONTHS_PERIODS: DatePeriodsEnum[];
export declare const QUARTERS_PERIODS: DatePeriodsEnum[];
export declare const DAYS_OF_WEEK: ReadonlyArray<{
    id: number;
    name: string;
}>;
/**
 * @config-entity
 * @stable [17.12.2019]
 */
export interface IDateTimeConfigEntity<TDate = Date> extends IDateWrapper<DateTimeLikeTypeT | TDate>, IDurationWrapper<StringNumberT>, IIndexWrapper, IInputFormatWrapper, IInputTimeFormatWrapper, IIsoWeekWrapper, IOutputFormatWrapper, IOutputTimeFormatWrapper, IStrictWrapper, ITimeWrapper, IUnitWrapper<string>, IZoneWrapper {
}
/**
 * @stable [07.03.2020]
 */
export declare type DatesRangeValueT = Array<DateTimeLikeTypeT | DatePeriodsEnum>;
/**
 * @entity
 * @stable [26.03.2020]
 */
export interface IDatePeriodModeEntity extends IPeriodModeWrapper<DatePeriodsEnum> {
}
/**
 * @entity
 * @stable [26.03.2020]
 */
export interface IDatePeriodTypeEntity extends IPeriodTypeWrapper<DatePeriodsEnum> {
}
/**
 * @entity
 * @stable [07.03.2020]
 */
export interface IDatesRangeEntity extends IFromToEntity<DateTimeLikeTypeT>, IDatePeriodModeEntity {
}
/**
 * @config-entity
 * @stable [21.01.2020]
 */
export interface IMinMaxDatesRangeConfigEntity extends IDateWrapper<Date>, IMaxDateWrapper<Date>, IMinDateWrapper<Date> {
}
/**
 * @config-entity
 * @stable [22.01.2020]
 */
export interface IPersonAgeConfigEntity<TDate = Date> extends IDateTimeConfigEntity<TDate>, IBirthdayWrapper {
}
/**
 * @entity
 * @stable [07.01.2020]
 */
export interface IDayOfYearEntity extends IDayWrapper, IFromToEntity<boolean>, IMonthWrapper, IYearWrapper {
}
/**
 * @entity
 * @stable [07.01.2020]
 */
export interface IFromToDayOfYearEntity extends IFromToEntity<IDayOfYearEntity> {
}
/**
 * @entity
 * @stable [03.01.2020]
 */
export interface ICalendarDayEntity extends IDayOfYearEntity, ICurrentWrapper<boolean>, IDateWrapper<Date>, INextWrapper<boolean>, IPreviousWrapper<boolean>, ITodayWrapper<boolean> {
}
/**
 * @entity
 * @stable [03.01.2020]
 */
export interface ICalendarWeekEntity extends IEntityIdTWrapper {
    [index: number]: ICalendarDayEntity;
}
/**
 * @entity
 * @stable [03.01.2020]
 */
export interface ICalendarEntity extends IDaysWrapper<ICalendarWeekEntity[]>, IDaysLabelsWrapper<string[]> {
}
