import { IBaseSelectProps } from '../component/field/select/base-select.interface';
import { IDefaultLayoutProps } from './layout-definition.interface';
import { IFieldProps } from '../configurations-definitions.interface';
import { IHeaderProps } from './header-definition.interface';
import { ITitleProps } from './title-definition.interface';
/**
 * @stable [09.10.2019]
 */
export declare enum RegexpEnum {
    PRICE = "\\d+(\\.\\d{1,2})?",
    NUMBER = "[-+]?[0-9]*[.,]?[0-9]+",
    DIGITAL = "[0-9]+"
}
/**
 * @stable [09.10.2019]
 */
export declare const REGEXP: {
    DIGITAL: RegExp;
    PRICE: RegExp;
};
/**
 * @stable [25.12.2019]
 */
export interface IDateTimeSettingsEntity {
    currentDate?: Date;
    dateTimeFormat?: string;
    maxDate?: Date;
    minDate?: Date;
    uiDateFormat?: string;
    uiDateMask?: Array<string | RegExp>;
    uiDatePattern?: string;
    uiDefaultTime?: string;
    uiTimeFormat?: string;
    uiYearMonthFormat?: string;
    uiYearPattern?: string;
}
/**
 * @stable [25.12.2019]
 */
export declare const DEFAULT_DATE_TIME_SETTINGS_ENTITY: Readonly<IDateTimeSettingsEntity>;
/**
 * @stable [29.11.0219]
 */
export interface ICurrencySettingsEntity {
    uiLocale?: string;
    uiCurrency?: string;
    uiShortCurrency?: string;
}
/**
 * @stable [15.10.2019]
 */
export declare const DEFAULT_CURRENCY_SETTINGS_ENTITY: Readonly<ICurrencySettingsEntity>;
/**
 * @entity
 * @stable [04.02.2020]
 */
export interface IComponentsSettingsEntity {
    baseSelect?: IBaseSelectProps;
    defaultLayout?: IDefaultLayoutProps;
    field?: IFieldProps;
    header?: IHeaderProps;
    title?: ITitleProps;
}
/**
 * @default-entity
 * @stable [24.03.2020]
 */
export declare const DEFAULT_COMPONENTS_SETTINGS_ENTITY: Readonly<IComponentsSettingsEntity>;
/**
 * @entity
 * @stable [09.01.2020]
 */
export interface IRoutesSettingsEntity {
    home?: string;
    logout?: string;
    oauthCallback?: string;
    oauthSignIn?: string;
}
/**
 * @default-entity
 * @stable [09.01.2020]
 */
export declare const DEFAULT_ROUTES_SETTINGS_ENTITY: Readonly<IRoutesSettingsEntity>;
/**
 * @entity
 * @stable [13.03.2020]
 */
export interface IOAuthSettingsEntity {
    clientId?: string;
    scope?: string;
}
/**
 * @default-entity
 * @stable [13.03.2020]
 */
export declare const DEFAULT_OAUTH_SETTINGS_ENTITY: Readonly<IOAuthSettingsEntity>;
/**
 * @entity
 * @stable [09.01.2020]
 */
export interface IAsyncLibrariesSettingsEntity {
    googleMaps?: string;
}
/**
 * @default-entity
 * @stable [09.01.2020]
 */
export declare const DEFAULT_ASYNC_LIBRARIES_SETTINGS_ENTITY: Readonly<IAsyncLibrariesSettingsEntity>;
/**
 * @stable [10.01.2020]
 */
export interface IGoogleMapsSettingsEntity {
    componentRestrictions?: {
        country?: string;
    };
    lat?: number;
    libraries?: string;
    lng?: number;
    prettyZoom?: number;
    zoom?: number;
}
/**
 * @default-entity
 * @stable [10.01.2020]
 */
export declare const DEFAULT_GOOGLE_MAPS_SETTINGS_ENTITY: Readonly<IGoogleMapsSettingsEntity>;
/**
 * @stable [29.11.0219]
 */
export interface IPhoneSettingsEntity {
    countryAbbr?: string;
    uiMask?: Array<string | RegExp>;
}
/**
 * @stable [29.11.0219]
 */
export declare const DEFAULT_PHONE_SETTINGS_ENTITY: Readonly<IPhoneSettingsEntity>;
/**
 * @entity
 * @stable [06.02.2020]
 */
export interface IUrlsSettingsEntity {
    emptyAvatar?: string;
    pdfWorker?: string;
}
/**
 * @default-entity
 * @stable [06.02.2020]
 */
export declare const DEFAULT_URLS_SETTINGS_ENTITY: Readonly<IUrlsSettingsEntity>;
/**
 * @stable [07.10.2019]
 */
export interface IMessagesSettingsEntity {
    ADDRESS_SELECTION?: string;
    AN_ERROR_OCCURRED_DURING_LOADING_THE_FILE?: string;
    APPLICATION_IS_INITIALIZING?: string;
    APPLY?: string;
    BUILD?: string;
    CHANGES_YOU_MADE_WILL_NOT_BE_SAVED?: string;
    CLEAR_ALL?: string;
    CLOSE?: string;
    COMPARE_TO?: string;
    CREATE?: string;
    CUSTOM?: string;
    DATE?: string;
    DAY?: string;
    DETAILS_INFO?: string;
    DIALOG_ACCEPT?: string;
    DIALOG_CANCEL?: string;
    DIALOG_DISCARD?: string;
    ENVIRONMENT?: string;
    ERROR?: string;
    FILTER_PLACEHOLDER?: string;
    FILTERS?: string;
    LAST_MONTH?: string;
    LAST_QUARTER?: string;
    LAST_WEEK?: string;
    LAST_YEAR?: string;
    LOG_OUT?: string;
    NEW_APP_VERSION_HAS_BEEN_DEPLOYED?: string;
    NO_DATA?: string;
    OK?: string;
    PATH?: string;
    PLEASE_WAIT?: string;
    PLS_SEND_THIS_SCR_TO_SUPPORT_MANAGER?: string;
    PREVIEW?: string;
    PUT_MARKER_HERE?: string;
    RESET?: string;
    RESTART_APP?: string;
    SAVE?: string;
    SETTINGS?: string;
    SOMETHING_WENT_WRONG?: string;
    THIS_MONTH?: string;
    THIS_QUARTER?: string;
    THIS_WEEK?: string;
    TODAY?: string;
    UNKNOWN_ERROR?: string;
    USER?: string;
    WAITING?: string;
    YEAR?: string;
    YESTERDAY?: string;
}
/**
 * @stable [07.10.2019]
 */
export declare const DEFAULT_MESSAGES_SETTINGS_ENTITY: Readonly<IMessagesSettingsEntity>;
