"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var action_builder_1 = require("../../component/action.builder");
var chained_middleware_1 = require("./chained.middleware");
var util_1 = require("../../util");
var default_form_changes_middleware_1 = require("./default-form-changes.middleware");
/**
 * @stable [27.03.2020]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IChainedMiddlewareConfigEntity<TState, TEntity extends IEntity>}
 */
var asChainedConfigEntity = function (config) {
    return ({
        action: config.action,
        nextSection: config.formSection,
        path: config.path,
        state: config.state,
    });
};
/**
 * @stable [20.10.2019]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeCreateEntityMiddleware = function (config) {
    return util_1.ifNotNilThanValue(chained_middleware_1.makeChainedMiddleware(asChainedConfigEntity(config)), function (actions) { return util_1.notNilValuesArrayFilter.apply(void 0, actions.concat([default_form_changes_middleware_1.makeDefaultFormChangesMiddleware(config)])); });
};
/**
 * @stable [27.03.2020]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeSelectEntityMiddleware = function (config) {
    var action = config.action;
    var selected = util_1.selectSelectedEntityFromAction(action);
    return config.lazyLoading
        ? [
            action_builder_1.ListActionBuilder.buildLazyLoadAction(config.listSection, util_1.defValuesFilter({
                selected: selected,
                preventEffects: util_1.selectPreventEffectsFromAction(action),
                previousAction: util_1.selectPreviousActionFromAction(action),
            }))
        ]
        : chained_middleware_1.makeChainedMiddleware(__assign({}, asChainedConfigEntity(config), { payload: selected }));
};
/**
 * @stable [27.03.2020]
 * @param {IEditedListMiddlewareConfigEntity<TEntity extends IEntity, TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeLazyLoadedEntityMiddleware = function (config) {
    var action = config.action;
    var result = util_1.ifNotNilThanValue(util_1.selectPreviousActionTypeFromAction(action), function (previousActionType) { return [redux_effects_promise_1.EffectsAction.create(redux_effects_promise_1.EffectsActionBuilder.buildDoneActionType(previousActionType))]; }, []).concat(chained_middleware_1.makeChainedMiddleware(__assign({}, asChainedConfigEntity(config), { payload: action.data })) || []);
    return util_1.orNull(util_1.isObjectNotEmpty(result), result);
};
//# sourceMappingURL=edited-list.middleware.js.map