"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
var filter_1 = require("./filter");
var nvl_1 = require("./nvl");
var entity_1 = require("./entity");
/**
 * @stable [16.12.2018]
 * @param {number} length
 * @returns {AnyT[]}
 */
exports.makeArray = function (length) { return Array.apply(null, { length: length }); };
/**
 * @stable [19.11.2018]
 * @param {number[]} array
 * @returns {number}
 */
exports.arrayMinValue = function (array) { return R.reduce(R.min, Infinity, array); };
/**
 * @stable [22.11.2018]
 * @param {number[]} array
 * @returns {number}
 */
exports.arrayNextMinNegativeValue = function (array) { return Math.min(Number(exports.arrayMinValue(array)), 0) - 1; };
/**
 * @stable [19.12.2018]
 * @param {TValue[]} array
 * @returns {boolean}
 */
exports.isArrayNotEmpty = function (array) { return Array.isArray(array) && !R.isEmpty(array); };
/**
 * @stable [28.01.2019]
 * @param {TValue[]} array
 * @param {number} limit
 * @returns {TValue[]}
 */
exports.subArray = function (array, limit) {
    return cond_1.ifNotNilThanValue(array, function () { return array.slice(0, Math.min(array.length, nvl_1.nvl(limit, array.length))); });
};
/**
 * @stable [04.10.2019]
 * @param {TValue[]} array
 * @param {TValue} initialItem
 * @param {(entity1: IEntity, entity2: IEntity) => boolean} predicate
 * @param {(previousItem: TValue) => TValue} itemFactory
 * @returns {TValue[]}
 */
exports.mergeArrayItem = function (array, initialItem, predicate, itemFactory) {
    if (predicate === void 0) { predicate = filter_1.SAME_ENTITY_PREDICATE; }
    var array0 = array || [];
    var hasEntity = exports.doesArrayContainEntity(array0, initialItem, predicate);
    var isMergedItemFactoryFn = type_1.isFn(itemFactory);
    var result = hasEntity
        ? array0
        : array0.concat([isMergedItemFactoryFn ? itemFactory(initialItem) : initialItem]);
    if (!hasEntity) {
        return result;
    }
    return result.map(function (itm) { return predicate(itm, initialItem)
        ? (isMergedItemFactoryFn
            ? itemFactory(itm) // Custom creating
            : initialItem // Replace
        )
        : itm; });
};
/**
 * @stable [19.10.2019]
 * @param {TEntity[]} data
 * @param {IEntityIdTWrapper} entity
 * @param {<TEntity extends IEntityIdTWrapper>(entity1: TEntity, entity2: TEntity) => boolean} redicate
 * @returns {boolean}
 */
exports.doesArrayContainEntity = function (data, entity, redicate) {
    if (redicate === void 0) { redicate = filter_1.SAME_ENTITY_PREDICATE; }
    return !entity_1.isNewEntity(entity) && R.any(function (item) { return redicate(item, entity); }, data || []);
};
/**
 * @stable [31.08.2019]
 * @param {AnyT} values
 * @returns {boolean}
 */
exports.areArrayValuesNotNil = function () {
    var values = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        values[_i] = arguments[_i];
    }
    return cond_1.ifNotNilThanValue(values, function () { return filter_1.notNilValuesArrayFilter.apply(void 0, values).length === values.length; }, false);
};
//# sourceMappingURL=array.js.map