"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var definitions_interface_1 = require("../definitions.interface");
/**
 * @stable [05.05.2019]
 * @param {number} num
 * @param {number} precision
 * @returns {number}
 */
exports.roundByPrecision = function (num, precision) {
    if (precision === void 0) { precision = definitions_interface_1.DEFAULT_CURRENCY_PRECISION_VALUE; }
    return Number(Math.round(Number(num + "e" + precision)) + "e-" + precision);
};
/**
 * @stable [05.05.2019]
 * @param {number} num
 * @param {number} divider
 * @returns {number}
 */
exports.roundDownByDivider = function (num, divider) {
    return Math.floor(num - num % divider);
};
/**
 * @stable [13.05.2019]
 * @param {number} num
 * @param {number} precision
 * @returns {number}
 */
exports.invertCurrency = function (num, precision) {
    if (precision === void 0) { precision = definitions_interface_1.DEFAULT_CURRENCY_PRECISION_VALUE; }
    var result = exports.roundByPrecision(num, precision); // To exclude the "-0" case
    return result === 0 ? result : result * -1;
};
/**
 * @stable [26.06.2019]
 * @param {number} value
 * @param {number} total
 * @returns {number}
 */
exports.percent = function (value, total) { return total === 0 ? 0 : (value * 100) / total; };
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @returns {number}
 */
exports.proportion = function (value, total) { return (value * total) / 100; };
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @returns {number}
 */
exports.residueRoundDownByDivider = function (value, total) { return total - exports.roundDownByDivider(total, value); };
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @param {number} offValue
 * @returns {number}
 */
exports.roundedProportion = function (value, total, offValue) {
    if (offValue === void 0) { offValue = definitions_interface_1.ONE_DOLLAR_VALUE; }
    var result0 = exports.proportion(value, total);
    return result0 + exports.residueRoundDownByDivider(offValue, total - result0);
};
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @param {number} offValue
 * @param {number} precisionValue
 * @returns {number}
 */
exports.roundedByPrecisionProportion = function (value, total, offValue, precisionValue) {
    if (offValue === void 0) { offValue = definitions_interface_1.ONE_DOLLAR_VALUE; }
    if (precisionValue === void 0) { precisionValue = definitions_interface_1.DEFAULT_CURRENCY_PRECISION_VALUE; }
    return exports.roundByPrecision(exports.roundedProportion(value, total, offValue), precisionValue);
};
//# sourceMappingURL=number.js.map