import { IEffectsAction } from 'redux-effects-promise';
import { IChangesWrapper, IDataWrapper, IEntity, IEntityIdTWrapper, IEntityWrapper, IFormWrapper, IListWrapper, IPreventEffectsWrapper, ISelectedWrapper, ITokenWrapper, ITypeWrapper, IValidWrapper } from '../definitions.interface';
import { IDictionariesWrapperEntity, IPreviousActionWrapperEntity, ITransportWrapperEntity, IUserWrapperEntity } from '../definition';
/**
 * @stable [27.03.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
export declare const selectEntityId: (entity: IEntityIdTWrapper) => string | number;
/**
 * @stable [29.02.2020]
 * @param {IFormWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectForm: <TValue>(wrapper: IFormWrapper<TValue>) => TValue;
/**
 * @stable [27.03.2020]
 * @param {IListWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectList: <TValue>(wrapper: IListWrapper<TValue>) => TValue;
/**
 * @stable [26.03.2020]
 * @param {ITypeWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectType: <TValue>(wrapper: ITypeWrapper<TValue>) => TValue;
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectToken: <TValue = string>(wrapper: ITokenWrapper<TValue>) => TValue;
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult = IEntity>(entity: IChangesWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectEntity: <TResult = IEntity>(entity: IEntityWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
export declare const selectData: <TData>(wrapper: IDataWrapper<TData>) => TData;
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectValid: (wrapper: IValidWrapper) => boolean;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectValidFromAction: (wrapper: IEffectsAction) => boolean;
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectPreventEffects: (wrapper: IPreventEffectsWrapper<boolean>) => boolean;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectPreventEffectsFromAction: (wrapper: IEffectsAction) => boolean;
/**
 *
 * @param {IPreviousActionWrapperEntity} wrapper
 * @returns {IEffectsAction}
 */
export declare const selectPreviousAction: (wrapper: IPreviousActionWrapperEntity) => IEffectsAction;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
export declare const selectPreviousActionFromAction: (wrapper: IEffectsAction) => IEffectsAction;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
export declare const selectPreviousActionTypeFromAction: (action: IEffectsAction) => string;
/**
 * @stable [27.03.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
export declare const selectSelected: <TEntity extends IEntity>(entity: ISelectedWrapper<TEntity>) => TEntity;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectSelectedEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
export declare const selectSelectedEntityIdFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => string | number;
/**
 * @stable [28.03.2020]
 * @param {IUserWrapperEntity<TUser>} entity
 * @returns {TUser}
 */
export declare const selectUser: <TUser>(entity: IUserWrapperEntity<TUser>) => TUser;
/**
 * @stable [28.03.2020]
 * @param {ITransportWrapperEntity<TTransport>} entity
 * @returns {TTransport}
 */
export declare const selectTransport: <TTransport>(entity: ITransportWrapperEntity<TTransport>) => TTransport;
/**
 * @stable [28.03.2020]
 * @param {IDictionariesWrapperEntity<TDictionaries>} entity
 * @returns {TDictionaries}
 */
export declare const selectDictionaries: <TDictionaries>(entity: IDictionariesWrapperEntity<TDictionaries>) => TDictionaries;
