"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var nvl_1 = require("./nvl");
var cond_1 = require("./cond");
/**
 * @stable [27.03.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
exports.selectEntityId = function (entity) { return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.id; };
/**
 * @stable [29.02.2020]
 * @param {IFormWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectForm = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.form; };
/**
 * @stable [27.03.2020]
 * @param {IListWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectList = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.list; };
/**
 * @stable [26.03.2020]
 * @param {ITypeWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectType = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.type; };
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectToken = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.token;
};
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectChanges = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.changes;
};
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.entity;
};
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.data;
};
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
exports.selectValid = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.valid;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectValidFromAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : exports.selectValid(wrapper.data);
};
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
exports.selectPreventEffects = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.preventEffects;
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectPreventEffectsFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.coalesce(exports.selectPreventEffects(wrapper.data), exports.selectPreventEffects(wrapper.initialData));
};
/**
 *
 * @param {IPreviousActionWrapperEntity} wrapper
 * @returns {IEffectsAction}
 */
exports.selectPreviousAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.previousAction;
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
exports.selectPreviousActionFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.coalesce(exports.selectPreviousAction(wrapper.data), exports.selectPreviousAction(wrapper.initialData));
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
exports.selectPreviousActionTypeFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectPreviousActionFromAction(action), function (previousAction) { return exports.selectType(previousAction); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.03.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
exports.selectSelected = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.selected;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
exports.selectSelectedEntityFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectData(action), function (data) { return exports.selectSelected(data); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
exports.selectSelectedEntityIdFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectSelectedEntityFromAction(action), function (entity) { return exports.selectEntityId(entity); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [28.03.2020]
 * @param {IUserWrapperEntity<TUser>} entity
 * @returns {TUser}
 */
exports.selectUser = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.user;
};
/**
 * @stable [28.03.2020]
 * @param {ITransportWrapperEntity<TTransport>} entity
 * @returns {TTransport}
 */
exports.selectTransport = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.transport;
};
/**
 * @stable [28.03.2020]
 * @param {IDictionariesWrapperEntity<TDictionaries>} entity
 * @returns {TDictionaries}
 */
exports.selectDictionaries = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.dictionaries;
};
//# sourceMappingURL=select.js.map